@@ -113,6 +113,11 @@ class Roi:
         else:
             return self.roi[4:]
 
+    def shape(self):
+        h = self.roi[1] - self.roi[0]
+        w = self.roi[3] - self.roi[2]
+        return (h, w)
+
     def copy(self):
         if self.empty():
             return Roi()
